@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright 2011-2012 Codernity (http://codernity.com)
+# Copyright 2011-2013 Codernity (http://codernity.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -339,6 +339,17 @@ class Database(object):
         result = self._request(function, data)
         return self.__loads(result)
 
+    def revert_index(self, index_name, reindex=False, ind_kwargs=None):
+        if ind_kwargs is None:
+            ind_kwargs = {}
+        function = 'revert_index'
+        data = {"index_name": index_name,
+                "reindex": reindex,
+                "ind_kwargs": ind_kwargs}
+        result = self._request(function, data)
+        return self.__loads(result)
+
+
     def get_version(self):
         function = 'get_version'
         data = {}
